Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3)

Unified Diff: public/platform/WebNavigatorConnectProvider.h

Issue 831613002: Add WebNavigatorConnectCallbacks typedef. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: make ConnectCallbacks be declared in terms of added typedef Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/modules/navigatorconnect/NavigatorConnect.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: public/platform/WebNavigatorConnectProvider.h
diff --git a/public/platform/WebNavigatorConnectProvider.h b/public/platform/WebNavigatorConnectProvider.h
index f4e9f0d2eaa70eaf7f5ef07e39024bf8922ddd30..77b3b3ec57b2037a14c042a1f888a5b8b35f93bb 100644
--- a/public/platform/WebNavigatorConnectProvider.h
+++ b/public/platform/WebNavigatorConnectProvider.h
@@ -13,6 +13,8 @@ class WebMessagePortChannel;
class WebString;
class WebURL;
+typedef WebCallbacks<void, void> WebNavigatorConnectCallbacks;
+
class WebNavigatorConnectProvider {
public:
virtual ~WebNavigatorConnectProvider() { }
@@ -21,8 +23,9 @@ public:
// successful the service can communicate with the client over the given
// channel. The origin isn't passed as WebSecurityOrigin because that would
// be a layering violation (platform/ code shouldn't depend on web/ code).
- // Ownership of the WebMessagePortChannel and WebCallbacks is transferred to the provider.
- virtual void connect(const WebURL&, const WebString& origin, WebMessagePortChannel*, WebCallbacks<void, void>*) { }
+ // Ownership of the WebMessagePortChannel and WebNavigatorConnectCallbacks
+ // objects are both transferred to the provider.
+ virtual void connect(const WebURL&, const WebString& origin, WebMessagePortChannel*, WebNavigatorConnectCallbacks*) { }
};
} // namespace blink
« no previous file with comments | « Source/modules/navigatorconnect/NavigatorConnect.cpp ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698